@@ -86,7 +86,7 @@ mod test_award_block_reward {
         rt.set_balance(TokenAmount::from(9));
         rt.expect_validate_caller_addr(vec![*SYSTEM_ACTOR_ADDR]);
         assert_eq!(
-            ExitCode::ErrIllegalState,
+            ExitCode::USR_ILLEGAL_STATE,
             award_block_reward(
                 &mut rt,
                 *WINNER,
@@ -110,7 +110,7 @@ mod test_award_block_reward {
 
         for (reward, penalty) in &reward_penalty_pairs {
             assert_eq!(
-                ExitCode::ErrIllegalArgument,
+                ExitCode::USR_ILLEGAL_ARGUMENT,
                 award_block_reward(
                     &mut rt,
                     *WINNER,
@@ -178,7 +178,7 @@ mod test_award_block_reward {
             RawBytes::serialize(BigIntSer(&expected_reward)).unwrap(),
             expected_reward,
             RawBytes::default(),
-            ExitCode::Ok,
+            ExitCode::OK,
         );
         rt.expect_send(
             *BURNT_FUNDS_ACTOR_ADDR,
@@ -186,7 +186,7 @@ mod test_award_block_reward {
             RawBytes::default(),
             penalty.clone(),
             RawBytes::default(),
-            ExitCode::Ok,
+            ExitCode::OK,
         );
 
         let params = AwardBlockRewardParams {
@@ -253,7 +253,7 @@ mod test_award_block_reward {
             RawBytes::serialize(BigIntSer(&expected_reward)).unwrap(),
             expected_reward.clone(),
             RawBytes::default(),
-            ExitCode::ErrForbidden,
+            ExitCode::USR_FORBIDDEN,
         );
         rt.expect_send(
             *BURNT_FUNDS_ACTOR_ADDR,
@@ -261,7 +261,7 @@ mod test_award_block_reward {
             RawBytes::default(),
             expected_reward,
             RawBytes::default(),
-            ExitCode::Ok,
+            ExitCode::OK,
         );
 
         let params = AwardBlockRewardParams {
@@ -349,7 +349,7 @@ fn award_block_reward(
         .unwrap(),
         expected_payment.clone(),
         RawBytes::default(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
 
     if penalty > TokenAmount::from(0) {
@@ -359,7 +359,7 @@ fn award_block_reward(
             RawBytes::default(),
             expected_payment,
             RawBytes::default(),
-            ExitCode::Ok,
+            ExitCode::OK,
         );
     }
 
